@@ -8,11 +8,17 @@ describe 'ec2api::db::sync' do
 
       describe 'with default parameters' do
         exec_parameters = {
-            command: 'ec2-api-manage db_sync',
-            path: '/usr/bin',
-            user: 'ec2api',
-            group: 'ec2api',
-            refreshonly: true,
+          :command     => 'ec2-api-manage db_sync',
+          :path        =>'/usr/bin',
+          :user        => 'ec2api',
+          :group       => 'ec2api',
+          :refreshonly => true,
+          :subscribe   => [
+            'Anchor[ec2api::install::end]',
+            'Anchor[ec2api::config::end]',
+            'Anchor[ec2api::dbsync::begin]'
+          ],
+          :notify      => 'Anchor[ec2api::dbsync::end]',
         }
 
         it { is_expected.to compile.with_all_deps }
@@ -21,6 +27,8 @@ describe 'ec2api::db::sync' do
 
         it { is_expected.to contain_class('ec2api::params') }
 
+        it { is_expected.to contain_class('ec2api::deps') }
+
         it { is_expected.to contain_exec('ec2api_db_sync').with(exec_parameters) }
       end
 
